
modname = 'CMFPhoto'
version = '0.4rc1'
numversion = version.split('.') 

license = 'GPL'
copyright = '''(c) 2002-2003 Magnus Heino, Christian Heimes'''

author = "Christian Heimes"
author_email = "heimes@faho.rwth-aachen.de"

short_desc = "A photo product for CMF"
long_desc = """
"""

web = "http://www.sourceforge.net/projects/collective"
ftp = ""
mailing_list = "collective@lists.sourceforge.net"
